@@ -22,7 +22,7 @@ class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.2.1"
+  __version__ = "0.2.2"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
@@ -72,6 +72,9 @@ class mNotes(object):
     else:
       self._window.set_title("%s" % self.__pretty_app_name__)
 
+    self._draw_pencil = self._widgetTree.get_widget("bPencil")
+    self._draw_clear = self._widgetTree.get_widget("bClearDraw")
+    
     callbackMapping = {
       # EventsList Signal
       "on_Del_clicked": self._delete_note,
@@ -80,6 +83,7 @@ class mNotes(object):
       "on_bPick_clicked": self.button_cam,
       "on_bPencil_clicked": self.toggle_draw_button_pencil,
       "on_bClearDraw_clicked": self.toggle_draw_button_clear,
+      "on_notebook_switch_page": self._page_changed,
 
 #      "on_Liste_row_activated": self._row_selected,
     }
@@ -91,10 +95,20 @@ class mNotes(object):
       self._children_color_bg(self._window)
       self._window.connect("delete-event", self._win_closebox)
       self._window.show_all()      
-
+    
     self._drawview = self._widgetTree.get_widget("DrawView")
     self._drawview.connect("configure_event", self.draw_configure_event)
-    
+    self._drawview.set_events(gtk.gdk.EXPOSURE_MASK |
+        gtk.gdk.LEAVE_NOTIFY_MASK |
+        gtk.gdk.BUTTON_PRESS_MASK |
+        gtk.gdk.POINTER_MOTION_MASK |
+        gtk.gdk.POINTER_MOTION_HINT_MASK)        
+    self._drawview.set_size_request(-1,-1)
+    self._drawview.queue_draw()
+
+    self._draw_pencil.set_active(True)
+    self._draw_clear.set_active(False)
+
     self.pixmap = None
 #    self.pixmap = gtk.gdk.Pixmap(None, 800, 480)
 #    width, height = 720,480
@@ -104,6 +118,41 @@ class mNotes(object):
     self._current_note = None
     threading.Thread(target=self._idle_setup).start()
 
+  def _page_changed(self,widget,page,page_num):
+    print 'page changed :'+str(page_num)
+#    if page_num == 1:
+#      self._load_current_note_draw()
+
+  def _load_current_note_draw(self):
+    if self._current_note.draw == True:
+#      self._drawview.show()
+      pixbuf = gtk.gdk.pixbuf_new_from_file(self._current_note.get_draw_path())
+      if pixbuf == None:
+        pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 600, 400)
+      try:
+        self._drawview.window.draw_pixbuf(None,pixbuf,0,0,0,0)
+        self.pixmap,_ = pixbuf.render_pixmap_and_mask()
+        self.pixmap.draw_rectangle(self._drawview.get_style().white_gc, True,0, 0, 600, 400)
+        del pixbuf
+        self._current_note.draw_loaded = True
+      except StandardError,e:
+        print e
+        self._current_note.draw_loaded = False
+        pass
+    else:
+      self._current_note.draw_loaded = False
+      pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 600, 400)
+      try:
+        self._drawview.window.draw_pixbuf(None,pixbuf,0,0,0,0)
+        self.pixmap,_ = pixbuf.render_pixmap_and_mask()
+        self.pixmap.draw_rectangle(self._drawview.get_style().white_gc, True,0, 0, 600, 400)
+        del pixbuf
+        self._current_note.draw_loaded = True
+      except StandardError,e:
+        print e
+        self._current_note.draw_loaded = False
+        pass
+      
   def _save_current_note(self):
     if self._current_note != None:
       buffer = self._editor.get_buffer()
@@ -111,8 +160,8 @@ class mNotes(object):
       self._current_note.description = buffer.get_text(start,end)
       self._current_note.save_to_db()
 
-      if self._drawview.window != None:
-        width, height =self._drawview.window.get_size ()
+      if (self._drawview.window != None) and (self._current_note.draw_loaded == True):
+        width, height =600,400 #self._drawview.window.get_size ()
         pixbuf = gtk.gdk.Pixbuf (gtk.gdk.COLORSPACE_RGB, 0, 8, width, height)
         pixbuf.get_from_drawable(self._drawview.window, self._drawview.window.get_colormap (),0, 0, 0, 0, width, height)
         pixbuf.save (self._current_note.get_draw_path(), "jpeg")
@@ -139,27 +188,11 @@ class mNotes(object):
         self._photoview.set_from_file(self._current_note.get_photo_path())
       else:
         self._photoview.set_from_stock(gtk.STOCK_MISSING_IMAGE,gtk.STATE_NORMAL)
-      #load draw
-      if self._current_note.draw == True:
-        pixbuf = gtk.gdk.pixbuf_new_from_file(self._current_note.get_draw_path())
-#        width, height =self._drawview.window.get_size ()
-        if pixbuf ==None:
-          pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 800, 480)
-        try:
-          self._drawview.window.draw_pixbuf(None,pixbuf,0,0,0,0)
-          self.pixmap,_ = pixbuf.render_pixmap_and_mask()
-          del pixbuf
-        except StandardError,e:
-          print e
-          pass
-#        width, height =self._drawview.window.get_size ()
-#        self._drawview.window.draw_rgb_image(self._drawview.style.black_gc,0,0,width,height,'normal',pixbuf)
-
-#      width, height =self._drawview.window.get_size ()
-#      pixbuf = gtk.gdk.Pixbuf (gtk.gdk.COLORSPACE_RGB, 0, 8, width, height)
-#      pixbuf.get_from_drawable(self._drawview.window, self._drawview.window.get_colormap (),0, 0, 0, 0, width, height)
-#      pixbuf.save (self._current_note.get_draw_path(), "jpeg")
-
+      #load draw here only when the drawingarea have window so when selected page on the notebook
+      if self._widgetTree.get_widget("notebook1").get_current_page()==1:
+        self._load_current_note_draw()
+      else:
+        self._current_note.draw_loaded = False
     return
 
   def _search_note(self,widget):
@@ -257,15 +290,7 @@ class mNotes(object):
     self._drawview.connect("expose_event", self.draw_expose_event)
     self._drawview.connect("motion_notify_event", self.draw_motion_notify_event)
     self._drawview.connect("button_press_event", self.draw_button_press_event)
-    self._drawview.set_events(gtk.gdk.EXPOSURE_MASK |
-        gtk.gdk.LEAVE_NOTIFY_MASK |
-        gtk.gdk.BUTTON_PRESS_MASK |
-        gtk.gdk.POINTER_MOTION_MASK |
-        gtk.gdk.POINTER_MOTION_HINT_MASK)
-    self._drawview.queue_draw()
-    self._draw_pencil = self._widgetTree.get_widget("bPencil")
     self._draw_pencil.set_active(True)
-    self._draw_clear = self._widgetTree.get_widget("bClearDraw")
     self._draw_clear.set_active(False)
 
     self.notesListTree = self._widgetTree.get_widget("Liste")
@@ -327,6 +352,9 @@ class mNotes(object):
       self._draw_mode=1
 
   def draw_expose_event(self,widget, event):
+  
+    if self._current_note.draw_loaded == False:
+      self._load_current_note_draw()
     x, y, width, height = event.area
     gc = widget.get_style().fg_gc[gtk.STATE_NORMAL]
     widget.window.draw_drawable(gc, self.pixmap, x, y, x, y, width, height)
